@@ -1,6 +1,7 @@
 #include "urlgrabber.h"
 #include "cookiejar.h"
 #include "json.h"
+#include "utils.h"
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
 #include <QNetworkRequest>
@@ -175,11 +176,104 @@ void UrlGrabber::getVideoUrl(int service, const QString &id) {
     }
 }
 
+QString UrlGrabber::decryptYouTubeSignature(const QString &s) {
+    QString signature;
+
+    switch (s.size()) {
+    case 88: {
+        signature = s.at(48)
+                + Utils::reverseString(s.mid(68, 14))
+                + s.at(82)
+                + Utils::reverseString(s.mid(63, 4))
+                + s.at(85)
+                + Utils::reverseString(s.mid(49, 13))
+                + s.at(67)
+                + Utils::reverseString(s.mid(13, 35))
+                + s.at(3)
+                + Utils::reverseString(s.mid(4, 8))
+                + s.at(2)
+                + s.at(12);
+    }
+        break;
+    case 87: {
+        signature = s.at(62)
+                + Utils::reverseString(s.mid(63, 20))
+                + s.at(83)
+                + Utils::reverseString(s.mid(53, 9))
+                + s.at(0)
+                + Utils::reverseString(s.mid(3, 49));
+    }
+        break;
+    case 86: {
+        signature = s.mid(2, 61)
+                + s.at(82)
+                + s.mid(64, 18)
+                + s.at(63);
+    }
+        break;
+    case 85: {
+        signature = s.at(76)
+                + Utils::reverseString(s.mid(77, 6))
+                + s.at(83)
+                + Utils::reverseString(s.mid(61, 15))
+                + s.at(0)
+                + Utils::reverseString(s.mid(51, 9))
+                + s.at(1)
+                + Utils::reverseString(s.mid(3, 47));
+    }
+        break;
+    case 84: {
+        signature = Utils::reverseString(s.mid(37, 47))
+                + s.at(2)
+                + Utils::reverseString(s.mid(27, 9))
+                + s.at(3)
+                + Utils::reverseString(s.mid(4, 22))
+                + s.at(26);
+    }
+        break;
+    case 83: {
+        signature = s.at(52)
+                + Utils::reverseString(s.mid(56, 26))
+                + s.at(2)
+                + Utils::reverseString(s.mid(53, 2))
+                + s.at(82)
+                + Utils::reverseString(s.mid(37, 15))
+                + s.at(55)
+                + Utils::reverseString(s.mid(3, 33))
+                + s.at(36);
+    }
+        break;
+    case 82: {
+        signature = s.at(36)
+                + Utils::reverseString(s.mid(68, 13))
+                + s.at(81)
+                + Utils::reverseString(s.mid(41, 26))
+                + s.at(33)
+                + Utils::reverseString(s.mid(37, 3))
+                + s.at(40)
+                + s.at(35)
+                + s.at(0)
+                + s.at(67)
+                + Utils::reverseString(s.mid(1, 32))
+                + s.at(34);
+    }
+        break;
+    default:
+        break;
+    }
+
+    return signature;
+}
+
 void UrlGrabber::getYouTubeVideoUrl(const QString &id) {
     this->setBusy(true, tr("Loading video"));
-    QUrl url(QString("http://www.youtube.com/get_video_info?video_id=%1&el=detailpage&ps=default&eurl=&gl=US&hl=en").arg(id));
-    QNetworkRequest request;
-    request.setUrl(url);
+    QUrl url("https://www.youtube.com/watch");
+    url.addQueryItem("v", id);
+    url.addQueryItem("gl", "US");
+    url.addQueryItem("hl", "en");
+    url.addQueryItem("has_verified", "1");
+    QNetworkRequest request(url);
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(parseYouTubeVideoPage()));
     this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
@@ -198,22 +292,16 @@ void UrlGrabber::parseYouTubeVideoPage() {
         return;
     }
 
-    QString response(QByteArray::fromPercentEncoding(reply->readAll()));
+    QString response(reply->readAll());
 
-    if (!response.contains("url_encoded_fmt_stream_map=")) {
+    if (!response.contains("url_encoded_fmt_stream_map\":")) {
         qDebug() << response;
-        QUrl url("http://www.youtube.com");
-        url.setEncodedQuery(response.toUtf8());
 
-        if (url.hasQueryItem("reason")) {
-            emit error(url.queryItemValue("reason").replace('+', ' '));
-        }
-        else {
-            emit error(tr("Unable to retrieve video. Access may be restricted"));
-        }
+        QString message = response.section("unavailable-message\" class=\"message\">", 1, 1).section('<', 0, 0).trimmed();
+        emit error(message.isEmpty() ? tr("Unable to retrieve video. Access may be restricted") : message);
     }
     else {
-        response = response.section("url_encoded_fmt_stream_map=", 1, 1);
+        response = response.section("url_encoded_fmt_stream_map\":", 1, 1).section(", \"", 0, 0).trimmed().replace("\\u0026", "&");
         int unescapes = 0;
 
         while ((response.contains('%')) && (unescapes < 10)) {
@@ -221,19 +309,34 @@ void UrlGrabber::parseYouTubeVideoPage() {
             unescapes++;
         }
 
-        response = response.replace("sig=", "signature=").replace(",signature=", "&signature=");
+        bool encryptedSignatures = !response.contains("sig=");
+
+        if (encryptedSignatures) {
+            response = response.replace(QRegExp("[&,\"]s="), "&signature=");
+        }
+        else {
+            response = response.replace(QRegExp("[&,\"]sig="), "&signature=");
+        }
+
         QStringList urlStrings = response.split("url=", QString::SkipEmptyParts);
         QStringList sigs = response.split("signature=");
         QStringList signatures;
         QMap<int, QString> formats;
 
-        for (int i = 1; i < sigs.size(); i++) {
-            signatures << sigs.at(i).section(QRegExp("(&|,)"), 0, 0);
+        if (encryptedSignatures) {
+            for (int i = 1; i < sigs.size(); i++) {
+                signatures << this->decryptYouTubeSignature(sigs.at(i).section(QRegExp("(&|,)"), 0, 0));
+            }
+        }
+        else {
+            for (int i = 1; i < sigs.size(); i++) {
+                signatures << sigs.at(i).section(QRegExp("(&|,)"), 0, 0);
+            }
         }
 
         foreach (QString urlString, urlStrings) {
             if (urlString.startsWith("http")) {
-                QUrl url(urlString.section(QRegExp("(,|&|)itag="), 0, 1));
+                QUrl url(urlString.section(QRegExp("[&,\"]itag="), 0, 1));
                 int key = url.queryItemValue("itag").toInt();
 
                 if (key > 0) {
@@ -258,15 +361,9 @@ void UrlGrabber::parseYouTubeVideoPage() {
 
         if (!videoUrl.startsWith("http")) {
             qDebug() << response;
-            QUrl url("http://www.youtube.com");
-            url.setEncodedQuery(response.toUtf8());
 
-            if (url.hasQueryItem("reason")) {
-                emit error(url.queryItemValue("reason").replace('+', ' '));
-            }
-            else {
-                emit error(tr("Unable to retrieve video. Access may be restricted"));
-            }
+            QString message = response.section("unavailable-message\" class=\"message\">", 1, 1).section('<', 0, 0).trimmed();
+            emit error(message.isEmpty() ? tr("Unable to retrieve video. Access may be restricted") : message);
         }
         else {
             emit gotVideoUrl(QUrl(videoUrl), m_format);
@@ -448,9 +545,13 @@ void UrlGrabber::getAvailableVideoFormats(int service, const QString &id) {
 
 void UrlGrabber::getAvailableYouTubeVideoFormats(const QString &id) {
     this->setBusy(true, tr("Retrieving available video formats"));
-    QUrl url(QString("http://www.youtube.com/get_video_info?video_id=%1&el=detailpage&ps=default&eurl=&gl=US&hl=en").arg(id));
-    QNetworkRequest request;
-    request.setUrl(url);
+    QUrl url("https://www.youtube.com/watch");
+    url.addQueryItem("v", id);
+    url.addQueryItem("gl", "US");
+    url.addQueryItem("hl", "en");
+    url.addQueryItem("has_verified", "1");
+    QNetworkRequest request(url);
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkYouTubeVideoFormats()));
     this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
@@ -470,22 +571,16 @@ void UrlGrabber::checkYouTubeVideoFormats() {
     }
 
     QVariantList formats;
-    QString response(QByteArray::fromPercentEncoding(reply->readAll()));
+    QString response(reply->readAll());
 
-    if (!response.contains("url_encoded_fmt_stream_map=")) {
+    if (!response.contains("url_encoded_fmt_stream_map\":")) {
         qDebug() << response;
-        QUrl url("http://www.youtube.com");
-        url.setEncodedQuery(response.toUtf8());
 
-        if (url.hasQueryItem("reason")) {
-            emit error(url.queryItemValue("reason").replace('+', ' '));
-        }
-        else {
-            emit error(tr("Unable to retrieve video formats. Access may be restricted"));
-        }
+        QString message = response.section("unavailable-message\" class=\"message\">", 1, 1).section('<', 0, 0).trimmed();
+        emit error(message.isEmpty() ? tr("Unable to retrieve formats. Access may be restricted") : message);
     }
     else {
-        response = response.section("url_encoded_fmt_stream_map=", 1, 1);
+        response = response.section("url_encoded_fmt_stream_map\":", 1, 1).section(", \"", 0, 0).trimmed().replace("\\u0026", "&");
         int unescapes = 0;
 
         while ((response.contains('%')) && (unescapes < 10)) {
@@ -493,18 +588,33 @@ void UrlGrabber::checkYouTubeVideoFormats() {
             unescapes++;
         }
 
-        response = QByteArray::fromPercentEncoding(QByteArray::fromPercentEncoding(response.toUtf8())).replace("sig=", "signature=").replace(",signature=", "&signature=");
+        bool encryptedSignatures = !response.contains("sig=");
+
+        if (encryptedSignatures) {
+            response = response.replace(QRegExp("[&,\"]s="), "&signature=");
+        }
+        else {
+            response = response.replace(QRegExp("[&,\"]sig="), "&signature=");
+        }
+
         QStringList urlStrings = response.split("url=", QString::SkipEmptyParts);
         QStringList sigs = response.split("signature=");
         QStringList signatures;
 
-        for (int i = 1; i < sigs.size(); i++) {
-            signatures << sigs.at(i).section(QRegExp("(&|,)"), 0, 0);
+        if (encryptedSignatures) {
+            for (int i = 1; i < sigs.size(); i++) {
+                signatures << this->decryptYouTubeSignature(sigs.at(i).section(QRegExp("(&|,)"), 0, 0));
+            }
+        }
+        else {
+            for (int i = 1; i < sigs.size(); i++) {
+                signatures << sigs.at(i).section(QRegExp("(&|,)"), 0, 0);
+            }
         }
 
         foreach (QString urlString, urlStrings) {
             if ((urlString.startsWith("http")) && (!signatures.isEmpty())) {
-                QUrl url(urlString.section(QRegExp("(,|&|)itag="), 0, 1));
+                QUrl url(urlString.section(QRegExp("[&,\"]itag="), 0, 1));
                 int key = url.queryItemValue("itag").toInt();
                 QVariantMap format;
 
@@ -560,15 +670,9 @@ void UrlGrabber::checkYouTubeVideoFormats() {
 
     if (formats.isEmpty()) {
         qDebug() << response;
-        QUrl url("http://www.youtube.com");
-        url.setEncodedQuery(response.toUtf8());
 
-        if (url.hasQueryItem("reason")) {
-            emit error(url.queryItemValue("reason").replace('+', ' '));
-        }
-        else {
-            emit error(tr("Unable to retrieve video formats. Access may be restricted"));
-        }
+        QString message = response.section("unavailable-message\" class=\"message\">", 1, 1).section('<', 0, 0).trimmed();
+        emit error(message.isEmpty() ? tr("Unable to retrieve formats. Access may be restricted") : message);
     }
     else {
         emit gotVideoFormats(formats);
