@@ -89,6 +89,16 @@ QString Utils::serviceString(Services::VideoService service) {
     }
 }
 
+QString Utils::reverseString(const QString &string) {
+    QString reverse;
+
+    for (int i = string.size() - 1; i >= 0; i--) {
+        reverse.append(string.at(i));
+    }
+
+    return reverse;
+}
+
 void Utils::log(const QString &filePath, const QByteArray &message) {
     QFile lf(filePath);
 
@@ -100,5 +110,9 @@ void Utils::log(const QString &filePath, const QByteArray &message) {
 }
 
 QString Utils::versionNumberString() {
-    return QString("1.7.3");
+#ifdef SYMBIAN_OS
+    return QString("1.8.1");
+#else
+    return QString("1.7.5");
+#endif
 }
