@@ -17,7 +17,7 @@ class DailymotionChannelWindow : public StackedWindow
     Q_OBJECT
 
 public:
-    explicit DailymotionChannelWindow(Session *session, const QString &userId, QWidget *parent);
+    explicit DailymotionChannelWindow(const QString &userId, QWidget *parent);
 
 private:
     void clearMenuActions();
