@@ -4,7 +4,6 @@
 #include "stackedwindow.h"
 #include "../base/groupitem.h"
 
-class Session;
 class DailymotionGroupListModel;
 class ListView;
 class QLabel;
@@ -15,8 +14,8 @@ class DailymotionGroupListWindow : public StackedWindow
     Q_OBJECT
 
 public:
-    explicit DailymotionGroupListWindow(Session *session, QWidget *parent);
-    void setGroupFeed(const QString &feed);
+    explicit DailymotionGroupListWindow(QWidget *parent);
+    void setGroupFeed(const QUrl &feed);
     void search(const QString &query, Queries::QueryOrder order);
 
 private:
