@@ -3,7 +3,6 @@
 
 #include "abstracttab.h"
 
-class Session;
 class DailymotionSubscriptionListModel;
 class ListView;
 class QModelIndex;
@@ -16,7 +15,7 @@ class DailymotionSubscriptionsTab : public AbstractTab
 {
     Q_OBJECT
 public:
-    explicit DailymotionSubscriptionsTab(Session *session, QWidget *parent = 0);
+    explicit DailymotionSubscriptionsTab(QWidget *parent = 0);
 
 private:
     void setLandscapeLayout();
@@ -32,7 +31,6 @@ private slots:
     void showSubscriptionVideos();
 
 private:
-    Session *m_session;
     DailymotionSubscriptionListModel *m_model;
     ListView *m_listView;
     QMenu *m_contextMenu;
