@@ -1,12 +1,11 @@
 #include "twitterauthdialog.h"
-#include "../base/session.h"
+#include "../base/sharing.h"
 #include "webview.h"
 #include <QProgressBar>
 #include <QGridLayout>
 
-TwitterAuthDialog::TwitterAuthDialog(Session *session, QWidget *parent) :
+TwitterAuthDialog::TwitterAuthDialog(QWidget *parent) :
     AbstractDialog(parent),
-    m_session(session),
     m_webView(new WebView(this)),
     m_progressBar(new QProgressBar(this)),
     m_grid(new QGridLayout(this))
@@ -19,12 +18,13 @@ TwitterAuthDialog::TwitterAuthDialog(Session *session, QWidget *parent) :
     m_webView->enableSelectionSuppressor();
     m_progressBar->setTextVisible(false);
 
-    this->connect(m_session->sharing(), SIGNAL(gotTwitterAuthUrl(QUrl)), this, SLOT(setAuthUrl(QUrl)));
+    this->connect(Sharing::instance(), SIGNAL(gotTwitterAuthUrl(QUrl)), this, SLOT(setAuthUrl(QUrl)));
     this->connect(m_webView, SIGNAL(loadProgress(int)), m_progressBar, SLOT(setValue(int)));
     this->connect(m_webView, SIGNAL(loadStarted()), m_progressBar, SLOT(show()));
     this->connect(m_webView, SIGNAL(loadFinished(bool)), m_progressBar, SLOT(hide()));
+    this->connect(this, SIGNAL(rejected()), Sharing::instance(), SLOT(cancelTwitterSignIn()));
 
-    m_session->sharing()->getTwitterAuthUrl();
+    Sharing::instance()->getTwitterAuthUrl();
 
     this->onOrientationChanged();
 }
@@ -36,7 +36,7 @@ void TwitterAuthDialog::setAuthUrl(const QUrl &url) {
 
 void TwitterAuthDialog::checkUrlForToken(const QUrl &url) {
     if (url.toString().startsWith("https://sites.google.com/site/marxodian/home/cutetube")) {
-        m_session->sharing()->signInToTwitter(url);
+        Sharing::instance()->signInToTwitter(url);
         this->accept();
     }
 }
