@@ -13,6 +13,7 @@
 #include <QAction>
 #include <QGridLayout>
 #include <QDesktopServices>
+#include <QMaemo5Style>
 
 YouTubeProfileTab::YouTubeProfileTab(const QString &userId, QWidget *parent) :
     AbstractTab(parent),
@@ -25,7 +26,7 @@ YouTubeProfileTab::YouTubeProfileTab(const QString &userId, QWidget *parent) :
     m_locationLabel(new QLabel(this)),
     m_websiteLabel(new QLabel(this)),
     m_descriptionLabel(new QLabel(this)),
-    m_noProfileLabel(new QLabel(QString("<p style='color:#4d4d4d;font-size:40px;'><center><b>%1</b></center></p>").arg(tr("No profile found")), this)),
+    m_noProfileLabel(new QLabel(QString("<p style='color:%1;font-size:40px;'><center><b>%2</b></center></p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(tr("No profile found")), this)),
     m_subscriptionButton(new QPushButton(tr("Subscribe"))),
     m_watchLaterAction(new QAction(tr("Show 'Watch later' playlist"), this)),
     m_watchHistoryAction(new QAction(tr("Show watch history"), this)),
