@@ -4,7 +4,6 @@
 #include "abstractdialog.h"
 #include <QVariantMap>
 
-class Session;
 class YouTubeUploadCategorySelector;
 class QLineEdit;
 class QTextEdit;
@@ -20,7 +19,7 @@ class YouTubeUploadDialog : public AbstractDialog
     Q_OBJECT
 
 public:
-    explicit YouTubeUploadDialog(Session *session, QWidget *parent = 0);
+    explicit YouTubeUploadDialog(QWidget *parent = 0);
     
 private:
     void setLandscapeLayout();
@@ -32,7 +31,6 @@ private slots:
     void uploadVideo();
 
 private:
-    Session *m_session;
     QVariantMap m_metadata;
     QMaemo5ValueButton *m_fileSelector;
     QLineEdit *m_titleEdit;
