@@ -13,8 +13,8 @@ class YouTubeUserListWindow : public StackedWindow
     Q_OBJECT
 
 public:
-    explicit YouTubeUserListWindow(Session *session, QWidget *parent);
-    void setFeed(const QString &feed);
+    explicit YouTubeUserListWindow(QWidget *parent);
+    void setFeed(const QUrl &feed);
     void search(const QString &query);
     
 private:
