@@ -408,7 +408,7 @@ void Events::addEvents() {
         args.append(event.timestamp());
         args.append(event.action());
 
-        QDBusInterface("com.maemo.eventFeed", "/", "com.maemo.eventFeed").callWithArgumentList(QDBus::NoBlock, "addEvent", args);
+        QDBusInterface("com.maemo.eventFeed", "/", "com.maemo.eventFeed").callWithArgumentList(QDBus::Block, "addEvent", args);
     }
 #endif
     this->syncSuccess();
