@@ -2,13 +2,16 @@
 #define EVENTS_H
 
 #include "event.h"
-#include <QDateTime>
+#include <QVariant>
+#include <qplatformdefs.h>
 
 class YouTube;
 class Dailymotion;
 class Vimeo;
 class Database;
 class QNetworkAccessManager;
+class QDBusMessage;
+class QDBusError;
 
 class Events : public QObject
 {
@@ -34,13 +37,20 @@ private slots:
     void processDailymotionEvents();
     void getVimeoEvents();
     void processVimeoEvents();
+#ifdef MEEGO_EDITION_HARMATTAN
     void onThumbnailDownloaded();
+    void dbusRequestCompleted(const QDBusMessage &message);
+    void dbusError(const QDBusError &error, const QDBusMessage &message);
+#endif
 
 private:
     void init();
     void addEvents();
+#ifdef MEEGO_EDITION_HARMATTAN
     QString base64SerializedVariant(const QVariant &value) const;
     void downloadThumbnails();
+    void clearThumbnails();
+#endif
 
 private:
     QNetworkAccessManager *m_nam;
@@ -51,9 +61,6 @@ private:
     QList<Event> m_events;
     int m_index;
     bool m_initialized;
-    QDateTime m_youtubeLatest;
-    QDateTime m_dailymotionLatest;
-    QDateTime m_vimeoLatest;
 };
 
 #endif  //  EVENTS_H
